==> aliyun-python-sdk-dataworks-public-2.0.0.tar.gz: aliyun-python-sdk-dataworks-public-2.0.0/aliyunsdkdataworks_public/request/v20200518/GetBaselineKeyPathRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class GetBaselineKeyPathRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetBaselineKeyPath','dide')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Bizdate(self):
		return self.get_body_params().get('Bizdate')

	def set_Bizdate(self,Bizdate):
		self.add_body_params('Bizdate', Bizdate)

	def get_InGroupId(self):
		return self.get_body_params().get('InGroupId')

	def set_InGroupId(self,InGroupId):
		self.add_body_params('InGroupId', InGroupId)

	def get_BaselineId(self):
		return self.get_body_params().get('BaselineId')

	def set_BaselineId(self,BaselineId):
		self.add_body_params('BaselineId', BaselineId)

==> aliyun-python-sdk-dataworks-public-5.0.1.tar.gz: aliyun-python-sdk-dataworks-public-5.0.1/aliyunsdkdataworks_public/request/v20200518/GetBaselineKeyPathRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class GetBaselineKeyPathRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetBaselineKeyPath')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Bizdate(self): # String
		return self.get_body_params().get('Bizdate')

	def set_Bizdate(self, Bizdate):  # String
		self.add_body_params('Bizdate', Bizdate)
	def get_InGroupId(self): # Integer
		return self.get_body_params().get('InGroupId')

	def set_InGroupId(self, InGroupId):  # Integer
		self.add_body_params('InGroupId', InGroupId)
	def get_BaselineId(self): # Long
		return self.get_body_params().get('BaselineId')

	def set_BaselineId(self, BaselineId):  # Long
		self.add_body_params('BaselineId', BaselineId)
